==> libdatetime-locale-perl_1.16.orig.tar.gz: DateTime-Locale-1.16/share/lg.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "lg",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Bal",
    "Lw2",
    "Lw3",
    "Lw4",
    "Lw5",
    "Lw6",
    "Sab"
  ],
  day_format_narrow => [
    "B",
    "L",
    "L",
    "L",
    "L",
    "L",
    "S"
  ],
  day_format_wide => [
    "Balaza",
    "Lwakubiri",
    "Lwakusatu",
    "Lwakuna",
    "Lwakutaano",
    "Lwamukaaga",
    "Sabbiiti"
  ],
  day_stand_alone_abbreviated => [
    "Bal",
    "Lw2",
    "Lw3",
    "Lw4",
    "Lw5",
    "Lw6",
    "Sab"
  ],
  day_stand_alone_narrow => [
    "B",
    "L",
    "L",
    "L",
    "L",
    "L",
    "S"
  ],
  day_stand_alone_wide => [
    "Balaza",
    "Lwakubiri",
    "Lwakusatu",
    "Lwakuna",
    "Lwakutaano",
    "Lwamukaaga",
    "Sabbiiti"
  ],
  era_abbreviated => [
    "BC",
    "AD"
  ],
  era_narrow => [
    "BC",
    "AD"
  ],
  era_wide => [
    "Kulisito nga tannaza",
    "Bukya Kulisito Azaal"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ganda",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apu",
    "Maa",
    "Juu",
    "Jul",
    "Agu",
    "Seb",
    "Oki",
    "Nov",
    "Des"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Janwaliyo",
    "Febwaliyo",
    "Marisi",
    "Apuli",
    "Maayi",
    "Juuni",
    "Julaayi",
    "Agusito",
    "Sebuttemba",
    "Okitobba",
    "Novemba",
    "Desemba"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apu",
    "Maa",
    "Juu",
    "Jul",
    "Agu",
    "Seb",
    "Oki",
    "Nov",
    "Des"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Janwaliyo",
    "Febwaliyo",
    "Marisi",
    "Apuli",
    "Maayi",
    "Juuni",
    "Julaayi",
    "Agusito",
    "Sebuttemba",
    "Okitobba",
    "Novemba",
    "Desemba"
  ],
  name => "Ganda",
  native_language => "Luganda",
  native_name => "Luganda",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Kya1",
    "Kya2",
    "Kya3",
    "Kya4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Kyakuna 1",
    "Kyakuna 2",
    "Kyakuna 3",
    "Kyakuna 4"
  ],
  quarter_stand_alone_abbreviated => [
    "Kya1",
    "Kya2",
    "Kya3",
    "Kya4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Kyakuna 1",
    "Kyakuna 2",
    "Kyakuna 3",
    "Kyakuna 4"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/lg.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "lg",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Bal",
    "Lw2",
    "Lw3",
    "Lw4",
    "Lw5",
    "Lw6",
    "Sab",
  ],
  day_format_narrow => [
    "B",
    "L",
    "L",
    "L",
    "L",
    "L",
    "S",
  ],
  day_format_wide => [
    "Balaza",
    "Lwakubiri",
    "Lwakusatu",
    "Lwakuna",
    "Lwakutaano",
    "Lwamukaaga",
    "Sabbiiti",
  ],
  day_stand_alone_abbreviated => [
    "Bal",
    "Lw2",
    "Lw3",
    "Lw4",
    "Lw5",
    "Lw6",
    "Sab",
  ],
  day_stand_alone_narrow => [
    "B",
    "L",
    "L",
    "L",
    "L",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "Balaza",
    "Lwakubiri",
    "Lwakusatu",
    "Lwakuna",
    "Lwakutaano",
    "Lwamukaaga",
    "Sabbiiti",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Kulisito nga tannaza",
    "Bukya Kulisito Azaal",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ganda",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apu",
    "Maa",
    "Juu",
    "Jul",
    "Agu",
    "Seb",
    "Oki",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janwaliyo",
    "Febwaliyo",
    "Marisi",
    "Apuli",
    "Maayi",
    "Juuni",
    "Julaayi",
    "Agusito",
    "Sebuttemba",
    "Okitobba",
    "Novemba",
    "Desemba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apu",
    "Maa",
    "Juu",
    "Jul",
    "Agu",
    "Seb",
    "Oki",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janwaliyo",
    "Febwaliyo",
    "Marisi",
    "Apuli",
    "Maayi",
    "Juuni",
    "Julaayi",
    "Agusito",
    "Sebuttemba",
    "Okitobba",
    "Novemba",
    "Desemba",
  ],
  name => "Ganda",
  native_language => "Luganda",
  native_name => "Luganda",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Kya1",
    "Kya2",
    "Kya3",
    "Kya4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kyakuna 1",
    "Kyakuna 2",
    "Kyakuna 3",
    "Kyakuna 4",
  ],
  quarter_stand_alone_abbreviated => [
    "Kya1",
    "Kya2",
    "Kya3",
    "Kya4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kyakuna 1",
    "Kyakuna 2",
    "Kyakuna 3",
    "Kyakuna 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
